"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("../../core");
var UnitTimes = require("../unit-times");
var force_1 = require("./force");
/**
 * The derived unit for energy, work, quantity of heat ( <code>J</code> ).
 * One joule is the amount of work done when an applied force of 1 newton moves
 * through a distance of 1 metre in the direction of the force.
 * It is named after the English physicist James Prescott Joule (1818-1889).
 */
exports.Joule = UnitTimes.forceByLength("Joule", force_1.Newton, core_1.BaseUnits.Meter);
// Energy
exports.NewtonMeter = UnitTimes.forceByLength("NewtonMeter", force_1.Newton, core_1.BaseUnits.Meter);
exports.Kilojoule = core_1.UnitPrefix.Kilo("Kilojoule", exports.Joule);
exports.Megajoule = core_1.UnitPrefix.Mega("Megajoule", exports.Joule);
exports.Btu = core_1.Unit.timesNumber("Btu", 52752792631.0 / 50000000.0, exports.Joule);
exports.KiloBtu = core_1.UnitPrefix.Kilo("KiloBtu", exports.Btu);
exports.MegaBtu = core_1.UnitPrefix.Mega("MegaBtu", exports.Btu);
exports.Therm = core_1.Unit.timesNumber("Therm", 100000, exports.Btu);
//# sourceMappingURL=energy.js.map