"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("../../core");
var UnitDivide = require("../unit-divide");
var duration_1 = require("./duration");
/**
 * The derived unit for frequency ( <code>Hz</code> ).
 * A unit of frequency equal to one cycle per second. After Heinrich Rudolf Hertz (1857-1894),
 * German physicist who was the first to produce radio waves artificially.
 */
exports.Hertz = UnitDivide.dimentionlessByDuration("Hertz", core_1.Unit.One, core_1.BaseUnits.Second);
/**
 * The derived unit for activity of a radionuclide ( <code>Bq</code> ).
 * One becquerel is the radiation caused by one disintegration per second.
 * It is named after the French physicist, Antoine-Henri Becquerel (1852-1908).
 */
exports.Becquerel = UnitDivide.dimentionlessByDuration("Becquerel", core_1.Unit.One, core_1.BaseUnits.Second);
// Frequency
exports.RevolutionsPerMinute = UnitDivide.dimentionlessByDuration("RevolutionsPerMinute", core_1.Unit.One, duration_1.Minute);
exports.RevolutionsPerHour = UnitDivide.dimentionlessByDuration("RevolutionsPerHour", core_1.Unit.One, duration_1.Hour);
//# sourceMappingURL=frequency.js.map