"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var UnitDivide = require("../unit-divide");
var core_1 = require("../../core");
var energy_1 = require("./energy");
/**
 * The derived unit for power, radiant, flux ( <code>W</code> ).
 * One watt is equal to one joule per second.
 * It is named after the British scientist James Watt (1736-1819).
 */
exports.Watt = UnitDivide.energyByDuration("Watt", energy_1.Joule, core_1.BaseUnits.Second);
// Power
exports.KiloWatt = core_1.UnitPrefix.Kilo("KiloWatt", exports.Watt);
exports.MegaWatt = core_1.UnitPrefix.Mega("MegaWatt", exports.Watt);
exports.GigaWatt = core_1.UnitPrefix.Giga("GigaWatt", exports.Watt);
exports.BtuPerHour = core_1.Unit.divideNumber("BtuPerHour", 3600.0, core_1.Unit.timesNumber("", 52752792631.0 / 50000000.0, exports.Watt));
exports.TonCooling = core_1.Unit.timesNumber("TonCooling", 12000.0, exports.BtuPerHour);
exports.KiloBtuPerHour = core_1.UnitPrefix.Kilo("KiloBtuPerHour", exports.BtuPerHour);
exports.HorsePower = core_1.Unit.timesNumber("HorsePower", 745.699872, exports.Watt);
exports.VoltAmpere = core_1.Unit.createAlternate("VoltAmpere", "VA", exports.Watt);
//# sourceMappingURL=power.js.map