"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("../../core");
var UnitDivide = require("../unit-divide");
var force_1 = require("./force");
var area_1 = require("./area");
/**
 * The derived unit for pressure, stress ( <code>Pa</code> ).
 * One pascal is equal to one newton per square meter.
 * It is named after the French philosopher and mathematician Blaise Pascal (1623-1662).
 */
exports.Pascal = UnitDivide.forceByArea("Pascal", force_1.Newton, area_1.SquareMeter);
// Pressure
exports.KiloPascal = core_1.UnitPrefix.Kilo("KiloPascal", exports.Pascal);
exports.HectoPascal = core_1.UnitPrefix.Hecto("HectoPascal", exports.Pascal);
exports.NewtonPerSquareMeter = UnitDivide.forceByArea("NewtonPerSquareMeter", force_1.Newton, area_1.SquareMeter);
exports.PoundForcePerSquareInch = core_1.Unit.divideNumber("PoundForcePerSquareInch", 1290320000.0, core_1.Unit.timesNumber("", 8896443230521.0, exports.Pascal));
exports.PoundForcePerSquareFoot = core_1.Unit.timesNumber("PoundForcePerSquareFoot", 144.0, exports.PoundForcePerSquareInch);
exports.DeciPascal = core_1.UnitPrefix.Deci("DeciPascal", exports.Pascal);
// http://www.wolframalpha.com/input/?i=psi and select 'Show exact conversions'
exports.InchOfMercury = core_1.Unit.divideNumber("InchOfMercury", 152.0, core_1.Unit.timesNumber("", 514731.0, exports.Pascal));
// http://www.wolframalpha.com/input/?i=inHg and select 'Show exact conversions'
exports.InchOfWaterColumn = core_1.Unit.timesNumber("InchOfWaterColumn", 249.0889, exports.Pascal);
// http://www.wolframalpha.com/input/?i=inWC
exports.FeetOfWaterColumn = core_1.Unit.timesNumber("FeetOfWaterColumn", 2989.067, exports.Pascal);
exports.Bar = core_1.Unit.timesNumber("Bar", 100000.0, exports.Pascal);
exports.MilliBar = core_1.UnitPrefix.Milli("MilliBar", exports.Bar);
//# sourceMappingURL=pressure.js.map