"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("../../core");
var UnitDivide = require("../unit-divide");
var energy_1 = require("./energy");
var energy2_1 = require("./energy2");
/**
 * The derived unit for absorbed dose, specific energy (imparted), kerma ( <code>Gy</code> ).
 * One gray is equal to the dose of one joule of energy absorbed per one kilogram of matter.
 * It is named after the British physician L. H. Gray (1905-1965).
 */
exports.Gray = UnitDivide.energyByMass("Gray", energy_1.Joule, core_1.BaseUnits.Kilogram);
/**
 * The derived unit for dose equivalent ( <code>Sv</code> ).
 * One Sievert is equal is equal to the actual dose, in grays, multiplied by a "quality factor" which is
 * larger for more dangerous forms of radiation.
 * It is named after the Swedish physicist Rolf Sievert (1898-1966).
 */
exports.Sievert = UnitDivide.energyByMass("Sievert", energy_1.Joule, core_1.BaseUnits.Kilogram);
// Specific energy
exports.KilojoulePerKilogram = UnitDivide.energyByMass("KilojoulePerKilogram", energy_1.Kilojoule, core_1.BaseUnits.Kilogram);
exports.KiloWattHourPerKilogram = UnitDivide.energyByMass("KiloWattHourPerKilogram", energy2_1.KiloWattHour, core_1.BaseUnits.Kilogram);
exports.BtuPerPoundLb = core_1.Unit.minus("BtuPerPoundLb", 7.68, core_1.Unit.timesNumber("", 2.326, exports.KilojoulePerKilogram));
//# sourceMappingURL=specific-enthalpy.js.map